@@ -19,11 +19,14 @@ from django import http as django_http
 from django import shortcuts
 from django.template import defaultfilters
 from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
 from horizon import forms
 from horizon import messages
 from horizon import tables
+from horizon.utils import filters
+from muranoclient.common import exceptions as exc
 from oslo_log import log as logging
 
 from muranodashboard import api as api_utils
@@ -31,9 +34,8 @@ from muranodashboard.api import packages as pkg_api
 from muranodashboard.catalog import views as catalog_views
 from muranodashboard.environments import api
 from muranodashboard.environments import consts
-from muranodashboard.environments import forms as env_forms
+from muranodashboard.packages import consts as pkg_consts
 
-from muranoclient.common import exceptions as exc
 
 LOG = logging.getLogger(__name__)
 
@@ -86,11 +88,24 @@ class CreateEnvironment(tables.LinkAction):
 
 
 class DeleteEnvironment(tables.DeleteAction):
-    data_type_singular = _('Environment')
-    data_type_plural = _('Environments')
-    action_past = _('Start Deleting')
     redirect_url = "horizon:project:murano:environments"
 
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Environment",
+            u"Delete Environments",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Start Deleting Environment",
+            u"Start Deleting Environments",
+            count
+        )
+
     def allowed(self, request, environment):
         if environment:
             return environment.status not in (consts.STATUS_ID_DEPLOYING,
@@ -112,12 +127,24 @@ class AbandonEnvironment(tables.DeleteAction):
     help_text = _("This action cannot be undone. Any resources created by "
                   "this environment will have to be released manually.")
     name = 'abandon'
-    action_present = _('Abandon')
-    action_past = _('Abandoned')
-    data_type_singular = _('Environment')
-    data_type_plural = _('Environments')
     redirect_url = "horizon:project:murano:environments"
 
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Abandon Environment",
+            u"Abandon Environments",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Abandoned Environment",
+            u"Abandoned Environments",
+            count
+        )
+
     def allowed(self, request, environment):
         """Limit when 'Abandon Environment' button is shown
 
@@ -142,9 +169,22 @@ class AbandonEnvironment(tables.DeleteAction):
 
 
 class DeleteService(tables.DeleteAction):
-    data_type_singular = _('Component')
-    data_type_plural = _('Components')
-    action_past = _('Start Deleting')
+
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Component",
+            u"Delete Components",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Start Deleting Component",
+            u"Start Deleting Components",
+            count
+        )
 
     def allowed(self, request, service=None):
         status, version = _get_environment_status_and_version(request,
@@ -167,12 +207,24 @@ class DeleteService(tables.DeleteAction):
 
 class DeployEnvironment(tables.BatchAction):
     name = 'deploy'
-    action_present = _('Deploy')
-    action_past = _('Deployed')
-    data_type_singular = _('Environment')
-    data_type_plural = _('Environment')
     classes = ('btn-launch',)
 
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Deploy Environment",
+            u"Deploy Environments",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deployed Environment",
+            u"Deployed Environments",
+            count
+        )
+
     def allowed(self, request, environment):
         """Limit when 'Deploy Environment' button is shown
 
@@ -183,11 +235,11 @@ class DeployEnvironment(tables.BatchAction):
           or successful deploy or delete failure)
         """
         status = getattr(environment, 'status', None)
-        if (status != consts.STATUS_ID_DEPLOY_FAILURE
-           and not environment.has_new_services):
-                return False
-        if (status in consts.NO_ACTION_ALLOWED_STATUSES
-                or status == consts.STATUS_ID_READY):
+        if (status != consts.STATUS_ID_DEPLOY_FAILURE and
+                not environment.has_new_services):
+            return False
+        if (status in consts.NO_ACTION_ALLOWED_STATUSES or
+                status == consts.STATUS_ID_READY):
             return False
         return True
 
@@ -217,8 +269,8 @@ class DeployThisEnvironment(tables.Action):
         """
         status, version = _get_environment_status_and_version(request,
                                                               self.table)
-        if (status in consts.NO_ACTION_ALLOWED_STATUSES
-                or status == consts.STATUS_ID_READY):
+        if (status in consts.NO_ACTION_ALLOWED_STATUSES or
+                status == consts.STATUS_ID_READY):
             return False
 
         apps = self.table.data
@@ -277,6 +329,10 @@ class UpdateServiceRow(tables.Row):
 class UpdateName(tables.UpdateAction):
     def update_cell(self, request, datum, obj_id, cell_name, new_cell_value):
         try:
+            if not new_cell_value or new_cell_value.isspace():
+                message = _("The environment name field cannot be empty.")
+                messages.warning(request, message)
+                raise ValueError(message)
             mc = api_utils.muranoclient(request)
             mc.environments.update(datum.id, name=new_cell_value)
         except exc.HTTPConflict:
@@ -302,11 +358,9 @@ class EnvironmentsTable(tables.DataTable):
     name = tables.Column('name',
                          link='horizon:murano:environments:services',
                          verbose_name=_('Name'),
-                         form_field=forms.CharField(
-                             validators=env_forms.NAME_VALIDATORS,
-                             error_messages={'invalid':
-                                             env_forms.ENV_NAME_HELP_TEXT},),
-                         update_action=UpdateName)
+                         form_field=forms.CharField(required=False),
+                         update_action=UpdateName,
+                         truncate=40)
 
     status = tables.Column('status',
                            verbose_name=_('Status'),
@@ -353,7 +407,8 @@ class ServicesTable(tables.DataTable):
                               verbose_name=_('Last operation'),
                               filters=(defaultfilters.urlize, ))
     operation_updated = tables.Column('operation_updated',
-                                      verbose_name=_('Time updated'))
+                                      verbose_name=_('Time updated'),
+                                      filters=(filters.parse_isotime,))
 
     def get_object_id(self, datum):
         return datum['?']['id']
@@ -409,10 +464,15 @@ class ServicesTable(tables.DataTable):
             actions.extend(sorted(app_actions, key=lambda x: x.name))
         return actions
 
+    def get_repo_url(self):
+        return pkg_consts.MURANO_REPO_URL
+
+    def get_pkg_def_url(self):
+        return reverse('horizon:murano:packages:index')
+
     class Meta(object):
         name = 'services'
         verbose_name = _('Component List')
-        template = 'services/_data_table.html'
         no_data_message = _('No components')
         status_columns = ['status']
         row_class = UpdateServiceRow
@@ -437,9 +497,11 @@ class ShowDeploymentDetails(tables.LinkAction):
 
 class DeploymentsTable(tables.DataTable):
     started = tables.Column('started',
-                            verbose_name=_('Time Started'))
+                            verbose_name=_('Time Started'),
+                            filters=(filters.parse_isotime,))
     finished = tables.Column('finished',
-                             verbose_name=_('Time Finished'))
+                             verbose_name=_('Time Finished'),
+                             filters=(filters.parse_isotime,))
 
     status = tables.Column(
         'state',
@@ -450,7 +512,6 @@ class DeploymentsTable(tables.DataTable):
     class Meta(object):
         name = 'deployments'
         verbose_name = _('Deployments')
-        template = 'common/_data_table.html'
         row_actions = (ShowDeploymentDetails,)
 
 
@@ -467,4 +528,3 @@ class EnvConfigTable(tables.DataTable):
     class Meta(object):
         name = 'environment_configuration'
         verbose_name = _('Deployed Components')
-        template = 'common/_data_table.html'
