@@ -12,10 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from collections import OrderedDict
 import json
 
+from django.conf import settings
 from django.core.urlresolvers import reverse
-from django.utils.datastructures import SortedDict
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import tabs
@@ -75,7 +76,7 @@ class OverviewTab(tabs.Tab):
             if id == service_data['?']['status']:
                 status_name = name
 
-        detail_info = SortedDict([
+        detail_info = OrderedDict([
             ('Name', getattr(service_data, 'name', '')),
             ('ID', service_data['?']['id']),
             ('Type', tables.get_service_type(service_data) or 'Unknown'),
@@ -219,6 +220,13 @@ class EnvironmentServicesTab(tabs.TableTab):
 
         return services
 
+    def get_context_data(self, request, **kwargs):
+        context = super(EnvironmentServicesTab,
+                        self).get_context_data(request, **kwargs)
+        context['MURANO_USE_GLARE'] = getattr(settings, 'MURANO_USE_GLARE',
+                                              False)
+        return context
+
 
 class DeploymentTab(tabs.TableTab):
     slug = "deployments"
