@@ -13,7 +13,6 @@
 #    under the License.
 
 from django.core.urlresolvers import reverse
-from django import http
 from django.template import defaultfilters
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
@@ -55,42 +54,22 @@ class ImportPackage(tables.LinkAction):
 class PackagesFilterAction(tables.FilterAction):
     name = "filter_packages"
     filter_type = "server"
-    filter_choices = (('search', _("Name"), True),
-                      ('type', _("Type"), True))
+    filter_choices = (('search', _("KeyWord"), True),
+                      ('type', _("Type"), True),
+                      ('name', _("Name"), True))
 
 
-class DownloadPackage(tables.Action):
+class DownloadPackage(tables.LinkAction):
     name = 'download_package'
     verbose_name = _('Download Package')
+    url = 'horizon:murano:packages:download'
 
     def allowed(self, request, package):
         return True
 
-    @staticmethod
-    def get_package_name(data_table, app_id):
-        # TODO(tsufiev): should use more optimal search here
-        name = None
-        for pkg in data_table.data:
-            if pkg.id == app_id:
-                name = defaultfilters.slugify(pkg.name)
-                break
-        return name if name is not None else app_id
-
-    def single(self, data_table, request, app_id):
-        try:
-            body = api.muranoclient(request).packages.download(app_id)
-
-            content_type = 'application/octet-stream'
-            response = http.HttpResponse(body, content_type=content_type)
-            response['Content-Disposition'] = 'filename={name}.zip'.format(
-                name=self.get_package_name(data_table, app_id))
-            return response
-        except exc.HTTPException:
-            LOG.exception(_('Something went wrong during package downloading'))
-            redirect = reverse('horizon:murano:packages:index')
-            exceptions.handle(request,
-                              _('Unable to download package.'),
-                              redirect=redirect)
+    def get_link_url(self, app):
+        app_name = defaultfilters.slugify(app.name)
+        return reverse(self.url, args=(app_name, app.id))
 
 
 class ToggleEnabled(tables.BatchAction):
@@ -161,11 +140,35 @@ class TogglePublicEnabled(tables.BatchAction):
                 request,
                 msg,
                 redirect=reverse('horizon:murano:packages:index'))
+        except exc.HTTPConflict:
+            msg = _('Package or Class with the same name is already made '
+                    'public')
+            LOG.exception(msg)
+            messages.error(request, msg)
+            exceptions.handle(
+                request,
+                msg,
+                redirect=reverse('horizon:murano:packages:index'))
 
 
 class DeletePackage(tables.DeleteAction):
     name = 'delete_package'
-    data_type_singular = _('Package')
+
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Package",
+            u"Delete Packages",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Package",
+            u"Deleted Packages",
+            count
+        )
 
     def delete(self, request, obj_id):
         try:
@@ -203,12 +206,13 @@ class ModifyPackage(tables.LinkAction):
 
 
 class PackageDefinitionsTable(tables.DataTable):
-    name = tables.Column('name', verbose_name=_('Package Name'))
+    name = tables.Column('name',
+                         link="horizon:murano:packages:detail",
+                         verbose_name=_('Package Name'))
     tenant_name = tables.Column('tenant_name', verbose_name=_('Tenant Name'))
     enabled = tables.Column('enabled', verbose_name=_('Active'))
     is_public = tables.Column('is_public', verbose_name=_('Public'))
     type = tables.Column('type', verbose_name=_('Type'))
-    author = tables.Column('author', verbose_name=_('Author'))
     version = tables.Column(lambda obj: getattr(obj, 'version', None),
                             verbose_name=_('Version'))
     created_time = tables.Column('created',
@@ -226,13 +230,12 @@ class PackageDefinitionsTable(tables.DataTable):
     class Meta(object):
         name = 'packages'
         prev_pagination_param = 'marker'
-        verbose_name = _('Package Definitions')
-        template = 'common/_data_table.html'
+        verbose_name = _('Packages')
+        table_actions_menu = (ToggleEnabled,
+                              TogglePublicEnabled)
         table_actions = (PackagesFilterAction,
                          ImportPackage,
                          ImportBundle,
-                         ToggleEnabled,
-                         TogglePublicEnabled,
                          DeletePackage)
 
         row_actions = (ModifyPackage,
